/* *************************************************************************
 *  Copyright 2012 Jakob Gruber <jakob.gruber@gmail.com>                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
 ************************************************************************* */


#ifndef CONSTANTS_H
#define CONSTANTS_H

/* TODO: either ship this or choose another font */
const QString FONT_NAME = "Ubuntu Mono";
const QString ORGANIZATION_NAME = "picmi";
const int ZVALUE_BACKGROUND = -7;
const int ZVALUE_HIGHLIGHT = -3;
const int ZVALUE_CELLFRAME = 0;
const int ZVALUE_STREAKFRAME = 0;
const int ZVALUE_DIVIDER = 3;
const int ZVALUE_CELLITEM = 7;
const int ZVALUE_BANNER = 7;
const int ZVALUE_STREAKTEXT = 7;
const int SECTION_SIZE = 5;

#endif // CONSTANTS_H
